document.addEventListener('DOMContentLoaded', () => {
  const addBookmarkBtn = document.getElementById('addBookmark');
  const addBookmarkForm = document.getElementById('addBookmarkForm');
  const bookmarkForm = document.getElementById('bookmarkForm');
  const cancelAddBtn = document.getElementById('cancelAdd');
  const bookmarksGrid = document.getElementById('bookmarksGrid');
  const searchInput = document.getElementById('searchBookmarks');
  const categoryFilter = document.getElementById('categoryFilter');

  let bookmarks = JSON.parse(localStorage.getItem('bookmarks')) || [];

  function toggleForm() {
    addBookmarkForm.classList.toggle('hidden');
  }

  function getVideoId(url) {
    const regExp = /^.*(youtu.be\/|v\/|u\/\w\/|embed\/|watch\?v=|&v=)([^#&?]*).*/;
    const match = url.match(regExp);
    return match && match[2].length === 11 ? match[2] : null;
  }

  function renderBookmarks(bookmarksToRender = bookmarks) {
    bookmarksGrid.innerHTML = bookmarksToRender
      .map((bookmark, index) => `
        <article class="bookmark-card">
          <img 
            src="https://img.youtube.com/vi/${bookmark.videoId}/maxresdefault.jpg" 
            alt="${bookmark.title}"
            class="thumbnail"
          >
          <div class="bookmark-info">
            <h2 class="bookmark-title">${bookmark.title}</h2>
            <p class="bookmark-category">${bookmark.category || 'Uncategorized'}</p>
            <div class="bookmark-actions">
              <button onclick="window.open('https://youtube.com/watch?v=${bookmark.videoId}', '_blank')">
                Watch
              </button>
              <button onclick="deleteBookmark(${index})" style="background: #ef4444;">
                Delete
              </button>
            </div>
          </div>
        </article>
      `)
      .join('');
  }

  function saveBookmarks() {
    localStorage.setItem('bookmarks', JSON.stringify(bookmarks));
  }

  window.deleteBookmark = (index) => {
    bookmarks.splice(index, 1);
    saveBookmarks();
    renderBookmarks();
  };

  bookmarkForm.addEventListener('submit', (e) => {
    e.preventDefault();
    
    const videoUrl = document.getElementById('videoUrl').value;
    const videoId = getVideoId(videoUrl);
    
    if (!videoId) {
      alert('Please enter a valid YouTube URL');
      return;
    }

    const bookmark = {
      videoId,
      title: document.getElementById('videoTitle').value || 'Untitled Video',
      category: document.getElementById('videoCategory').value,
      dateAdded: new Date().toISOString()
    };

    bookmarks.unshift(bookmark);
    saveBookmarks();
    renderBookmarks();
    bookmarkForm.reset();
    toggleForm();
  });

  addBookmarkBtn.addEventListener('click', toggleForm);
  cancelAddBtn.addEventListener('click', toggleForm);

  searchInput.addEventListener('input', (e) => {
    const searchTerm = e.target.value.toLowerCase();
    const categoryValue = categoryFilter.value;
    
    const filtered = bookmarks.filter(bookmark => {
      const matchesSearch = bookmark.title.toLowerCase().includes(searchTerm);
      const matchesCategory = !categoryValue || bookmark.category === categoryValue;
      return matchesSearch && matchesCategory;
    });
    
    renderBookmarks(filtered);
  });

  categoryFilter.addEventListener('change', (e) => {
    const searchTerm = searchInput.value.toLowerCase();
    const categoryValue = e.target.value;
    
    const filtered = bookmarks.filter(bookmark => {
      const matchesSearch = bookmark.title.toLowerCase().includes(searchTerm);
      const matchesCategory = !categoryValue || bookmark.category === categoryValue;
      return matchesSearch && matchesCategory;
    });
    
    renderBookmarks(filtered);
  });

  renderBookmarks();
});